package de.fuberlin.wiwiss.semmf.descr;


import java.util.List;

import de.fuberlin.wiwiss.semmf.engine.Matcher;

/**
 * Each object holding cluster matching information must implement this interface,
 * in order to be compatible with the MatchingEngine.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified on 29.11.2006
 */
public interface NodeMatchingDescription {
	
	/**
	 * @return label of this node.
	 */
	public String getLabel();
	
	
	/**
	 * @return weight which represents the importance of this node among
	 * other nodes in a particular ClusterMatchingDescription
	 * The weight is a float number [0..1]. The sum of all node weights must
	 * equal 1.
	 */
	public float getWeight();
	
	
	/**
	 * @return RDQL path expression which will be evaluated by the matching engine 
	 * 		   in order to find the queryNode.
	 */
	public String getQueryNodePath();
	
	
	/**
	 * @return RDQL path expression which will be evaluated by the matching engine 
	 * 		   in order to find a particualr resourceNode.
	 */
	public String getResourceNodePath();
	
	
	/**
	 * @return Matcher which will calculate the similarity of the query and res nodes
	 */
	public Matcher getMatcher();
	
	
	/**
	 * In most cases the matching engine compares a value from a resource graph with
	 * the semantically corresponding value from a query graph (= the "required" value).
	 * But for some nodes it is reasonable to reverse the matching. A good example is 
	 * comparing job requirements with applicant's profile. If a person (query graph) 
	 * looks for a job (resource graph) then while comparing his skills with 
	 * skills required for a certain position the required skills from a resource graph
	 * (job description) become the "should be" values, thus the matching has to be reversed.    
	 * @return true if the matching should be reversed
	 */
	public boolean reverseMatching();
	
	
	/**
	 * @return true if this node has properties which should be matched
	 */
	public boolean hasProperties();
	
	
	/**
	 * @return list of objects implementing the PropertyMatchingDescription interface.
	 */	
	public List getPropertyMatchingDescriptionList();

}
