package de.fuberlin.wiwiss.semmf.descr;

import de.fuberlin.wiwiss.semmf.engine.Matcher;

/**
 * Each object holding property matching information must implement 
 * this interface, in order to be compatible with the MatchingEngine.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public interface PropertyMatchingDescription {

	
	/**
	 * @return label of this property.
	 */
	public String getLabel();
	
	
	/**
	 * @return weight which represents the importance of this property
	 * among other properties in a particular NodeMatchingDescription
	 * The weight is a float number [0..1]. The sum of all property weights 
	 * equals 1.
	 */
	public float getWeight();
	
	
	/**
	 * @return URI of the property of the query node
	 */
	public String getQueryPropertyURI();
	
	
	/**
	 * @return URI of the property of the resource node
	 */
	public String getResPropertyURI();
	
	
	/**
	 * @return Matcher which will calculate the similarity of the query 
	 * and res properties
	 */
	public Matcher getMatcher();
	
	
	/**
	 * In most cases the matching engine compares a value from a resource graph with
	 * the semantically corresponding value from a query graph (= the "required" value).
	 * But for some nodes it is reasonable to reverse the matching. A good example is 
	 * comparing job requirements with applicant's profile. If a person (query graph) 
	 * looks for a job (resource graph) then while comparing his skills with 
	 * skills required for a certain position the required skills from a resource graph
	 * (job description) become the "should be" values, thus the matching has to be reversed.    
	 * @return true if the matching should be reversed
	 */
	public boolean reverseMatching();
}
