package de.fuberlin.wiwiss.semmf.descr.impl;


import java.util.List;
import java.util.ArrayList;

import de.fuberlin.wiwiss.semmf.descr.ClusterMatchingDescription;
import de.fuberlin.wiwiss.semmf.descr.NodeMatchingDescription;

/**
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public class ClusterMatchingDescriptionImpl implements ClusterMatchingDescription{
    
    /**
     * Label of a particualar clluster
     */
    private String label;
    
    
    /**
     * Weight of a particular cluster
     */
    private float weight;
    
    
    /**
     * List with matching descriptions for all nodes inside
     * this cluster.
     */
    private List nodeMatchingDescriptionList = new ArrayList();
    
    
    /**
     * Constructor.
     * @param label label of this cluster
     * @param weight weight of this cluster
     */
    public ClusterMatchingDescriptionImpl (String label, float weight) {
        
        this.label = label;
        this.weight = weight;
    }
    
    
	/**
	 * Adds a new NodeMatchingDescription to List of NMD's
	 */
	public void addNodeMatchingDescription (NodeMatchingDescription nmd) {
	    
	    this.nodeMatchingDescriptionList.add(nmd);
	}
	
    
	/* **********************************************************************
	 * 		 Implementation of the ClusterMatchingDescription interface 
	 * **********************************************************************
	 */
    
	/**
	 * @return label of this cluster.
	 */
	public String getLabel() {
	    
	    return this.label;
	}
	
	
	/**
	 * @return weight which represents the importance of this cluster among
	 * other clusters in a MatchingDescription
	 * The weight is a float number [0..1]. The sum of all cluster weights 
	 * equals 1.
	 */
	public float getWeight() {
	    
	    return this.weight;
	}
	
	
	/**
	 * @return list of objects implementing the NodeMatchingResult interface.
	 * These objects hold information about the matching of RDFnodes
	 */	
	public List getNodeMatchingDescriptionList() {
	    
	    return this.nodeMatchingDescriptionList;
	}

}
