package de.fuberlin.wiwiss.semmf.engine;


import java.util.List;

import java.util.Comparator;

import de.fuberlin.wiwiss.semmf.result.ClusterMatchingResult;
import de.fuberlin.wiwiss.semmf.result.GraphMatchingResult;

/**
 * This comaprator is used by the matching engine to sort GraphMatchingResults
 * descending order, by the similarity of a given cluster.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public class ClusterSimComparator implements Comparator {
	
	
	/**
	 * Index of the cluster to be compared in the ClusterMatchingResult List
	 */
	private int indexInClusterList;
	
	
	/**
	 * Constructor
	 * @param indexInClusterList Index of the cluster to be compared 
	 * in the ClusterMatchingResultList
	 */
	public ClusterSimComparator (int indexInClusterList) {
		
		this.indexInClusterList = indexInClusterList;
	}
	
	
	/**
	 * Implementation of the Comparator's abstract method
	 */
	public int compare (Object gmr1, Object gmr2) {
	
		List cmrL1 = ((GraphMatchingResult) gmr1).getClusterMatchingResultList();
		List cmrL2 = ((GraphMatchingResult) gmr2).getClusterMatchingResultList();
		
		float sim1 = ((ClusterMatchingResult) cmrL1.get(indexInClusterList)).getSimilarity();
		float sim2 = ((ClusterMatchingResult) cmrL2.get(indexInClusterList)).getSimilarity();
	
		// this ensures a sorting in a descending manner
		return ( - Float.compare(sim1, sim2) );
		
	}

}