package de.fuberlin.wiwiss.semmf.engine;

import com.hp.hpl.jena.rdf.model.RDFNode;

/**
 * Each Matcher assigned to a NodeMatchingDescription and therefore passed to the
 * matching engine must implement this interface.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.2
 * last modified 29.11.2006
 */
public interface Matcher {

    
    /**
     * Calculates the similarity of two given RDFNodes. 
     * The RDFNodes may be Resources (having unique URI) or Literals
     * with numeric or String values.
     * It is up to the certain Matcher implementing this interface to handle these
     * values correctly according to their format.
     * @param queryNode node from the query graph
     * @param resNode node from the resource graph
     * @return the similarity between both nodes. The sim is a 
     * 		   float number from [0,1]
     */
    public float calcSim (RDFNode queryNode, RDFNode resNode);
}
