package de.fuberlin.wiwiss.semmf.engine;

import com.hp.hpl.jena.assembler.Assembler;
import com.hp.hpl.jena.assembler.Mode;
import com.hp.hpl.jena.assembler.assemblers.AssemblerBase;
import com.hp.hpl.jena.rdf.model.Literal;
import com.hp.hpl.jena.rdf.model.Resource;

import de.fuberlin.wiwiss.semmf.vocabulary.MD;

/**
 * A class reading a specification of parameters for a Numeric Matcher provided in
 * a matching description. 
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public class NumericMatcherAssembler extends AssemblerBase {
	
	/**
	 * Overrides the open() method of AssemblerBase
	 * @param matcherNode RDFNOde inside a matching description holding matcher
	 * specification.
	 */
	public Object open (Assembler ignore, Resource matcherNode, Mode ignore2) {
		
		// if these parameters are not specified in the matchingDescription.rdf
		// use these default values !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
		int decreaseSim = NumericMatcher.DEC_SIM_WITH_DEVIATION;
		float maxDevFraction = 0.5f;
		
		try {
			String ds = ((Literal) matcherNode.getProperty(MD.decreaseSim).getObject()).getValue().toString();
			if (ds.equalsIgnoreCase("upwards"))
				decreaseSim = NumericMatcher.DEC_SIM_UPWARDS;
			else if (ds.equalsIgnoreCase("downwards"))
				decreaseSim = NumericMatcher.DEC_SIM_DOWNWARDS;
			else if (ds.equalsIgnoreCase("with deviation"))
				decreaseSim = NumericMatcher.DEC_SIM_WITH_DEVIATION;
			// toDo: exception
			else {}
		}
		catch (java.lang.NullPointerException npe) {}					
		
		try {
			String mdf = ((Literal) matcherNode.getProperty(MD.maxDevFraction).getObject())
				.getValue().toString();
			mdf = mdf.replace(",", ".");
			maxDevFraction = Float.parseFloat(mdf);
		}
		// toDo: exception handling
		catch (java.lang.NumberFormatException nfe) {}
		catch (java.lang.NullPointerException npe) {}

		return new NumericMatcher(decreaseSim, maxDevFraction);
	}

}
