package de.fuberlin.wiwiss.semmf.engine;


import com.hp.hpl.jena.assembler.Assembler;
import com.hp.hpl.jena.assembler.Mode;
import com.hp.hpl.jena.assembler.assemblers.AssemblerBase;
import com.hp.hpl.jena.rdf.model.Literal;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.vocabulary.RDF;

import de.fuberlin.wiwiss.semmf.taxon.ExpMilestCalc;
import de.fuberlin.wiwiss.semmf.taxon.LinMilestCalc;
import de.fuberlin.wiwiss.semmf.taxon.Taxonomy;
import de.fuberlin.wiwiss.semmf.vocabulary.MD;

/**
 * A class reading a specification of parameters for a Taxonomic Matcher provided in
 * a matching description.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.3
 * last modified 29.11.2006
 */
public class TaxonomicMatcherAssembler extends AssemblerBase {
	
	
	/**
	 * Overrides the open() method of AssemblerBase
	 * @param matcherNode RDFNOde inside a matching description holding matcher
	 * specification.
	 */		
	public Object open (Assembler ignore, Resource matcherNode, Mode ignore2) {

		Matcher matcher = null;
		
		//		taxonomy		
		Resource taxonNode = (Resource) matcherNode.getProperty(MD.taxonomy).getObject();
		String taxonURL = ((Literal) taxonNode.getProperty(MD.taxonomyURL).getObject()).toString();
		String rootURI = ((Literal) taxonNode.getProperty(MD.rootConceptURI).getObject()).toString();
	
		Taxonomy t = new Taxonomy(taxonURL, rootURI);
		
		//milestonecalculator
		Resource milestCalcNode = (Resource) matcherNode.getProperty(MD.useMilestoneCalc).getObject();
		
		String mcType = ((Resource) milestCalcNode.getProperty(RDF.type).getObject()).getURI();
		if (mcType.equals(MD.LinMilestCalc.getURI())) {
			
			matcher = new TaxonomicMatcher(t, new LinMilestCalc()); 
		}
		else if (mcType.equals(MD.ExpMilestCalc.getURI())) {
			
			// if the k-factor is not specified in the matchingDescription.rdf
			// use the default value	
			float k=1.5f;
			
			try {
				k = Float.parseFloat(milestCalcNode.getProperty(MD.k_factor).getObject().toString());
			}		
			// toDo: exception handling
			catch (java.lang.NumberFormatException nfe) {}
			catch (java.lang.NullPointerException npe) {}
			
			matcher = new TaxonomicMatcher(t, new ExpMilestCalc(k));
			
		}		

		return matcher;
	}

}
