package de.fuberlin.wiwiss.semmf.result;

import java.util.List;

/**
 * This interface provides methods for representing the matching result of 
 * values inside a certain cluster.  
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public interface ClusterMatchingResult {

	
	/**
	 * @return label of the cluster specified in the matching description
	 */
	public String getLabel();
	
	
	/**
	 * @return aggregated similarity of all nodes from a query graph inside this 
	 * cluster matched against the corresponding cluster from a resource graph.  
	 */
	public float getSimilarity();
	
	
	/**
	 * @return weight which represents the importance of this cluster among
	 * other clusters in a GraphMatchingResult. 
	 * The weight is a float number [0..1]. The sum of all cluster weights 
	 * equals 1.
	 */
	public float getWeight();
	
	
	/**
	 * @return list of objects implementing the NodeMatchingResult interface.
	 * These objects hold information about the matching of RDFNodes
	 * from a query graph against RDFNodes from a resource graph
	 */	
	public List getNodeMatchingResultList();
}
