package de.fuberlin.wiwiss.semmf.result;

import java.util.List;
import com.hp.hpl.jena.rdf.model.Resource;

/**
 * When the method exec() is invoked on a MatchingEngine,
 * a MatchingResult object holding a List of ranked instances implementing 
 * this interface is returned. These objects are sorted in a descending manner
 * => the index starts at the object having the highest similarity.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public interface GraphMatchingResult {
	
	
	/**
	 * @return Jena Resource object representing the entry of the query
	 * graph which was matched against the resource graph, which entry, in turn, 
	 * is returned by the method getResourceGraphEntry().
	 */
	public Resource getQueryGraphEntryNode();
	
	
	/**
	 * @return Jena Resource object representing the entry of the resource
	 * graph which was matched against an query graph, which entry, in turn,
	 * is returned by the method getQueryGraphEntryNode().
	 */
	public Resource getResGraphEntryNode();
	
	
	/**
	 * @return similarity between both graphs
	 */
	public float getSimilarity();
	
	
	/**
	 * The RDFNodes to be matched can be grouped into thematic clusters 
	 * @return List of objects implementing the ClusterMatchingResult interface.
	 */
	public List getClusterMatchingResultList();
}
