package de.fuberlin.wiwiss.semmf.result;

import de.fuberlin.wiwiss.semmf.result.GraphMatchingResult;

/**
 * When the method exec() is invoked on a MatchingEngine,
 * a MatchingResult object holding a List of ranked instances of GraphMatchingDescription is returned. 
 * These objects are sorted in a descending manner
 * => the index starts at the object having the highest similarity.
 * 
 * This interface provides method for sorting and traversing the matching output.
 * 
 * @author Radoslaw Oldakowski
 * @version 1.0
 * last modified 29.11.2006  
*/
public interface MatchingResult {
	
	/**
	 * @return the number of GraphMatchingResults
	 */
	public int count();
	
	
	/**
	 * sorts all GraphMatching results by their overall similarity in descending order
	 */
	public void sortByGraphSim ();
	
	
	/**
	 * sorts all GraphMatching results by the given cluster similarity in descending order
	 * @param clusterLabel label provided in a matching description
	 */
	public void sortByClusterSim (String clusterLabel);

	
	/**
	 * sets the index of the Iterator to the first (best ranked) element in the List
	 */
	public void setToFirst ();
	
	
	/**
	 * @return the best ranked GraphMatchingResult
	 */
	public GraphMatchingResult getFirst() ;
	
	
	/**
	 * @return true is the is a next element in the ranked list of GraphMatchingResults
	 */
	public boolean hasNext();

	
	/**
	 * @return the next element in the ranked list of GraphMatchingResults
	 */
	public GraphMatchingResult next();
	
}
