package de.fuberlin.wiwiss.semmf.result;

import java.util.List;
import com.hp.hpl.jena.rdf.model.RDFNode;

/**
 * In Jena2 all property values are of type RDFNode (Resources or Literals).
 * If the property value is a blank node, then it may have further properties
 * which should be considered by the matching engine. In this case the method
 * getPropertyMatchingResultList() will return a list of objects representing
 * the matching reulst of each single property. 
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public interface NodeMatchingResult {

	
	/** 
	 * @return RDFNode from a query graph
	 */
	public RDFNode getQueryNode();
	
	
	/** 
	 * @return RDFNode resource graph
	 */
	public RDFNode getResNode();
	
	
	/**
	 * @return node label specified in a matching description.
	 */	
	public String getLabel();
	
	
	/**
	 * @return the similarity value of both nodes.
	 * If the node is a resource having properties this similarity value 
	 * includes the similarity of the nodes and the similarities of 
	 * their properties.
	 */
	public float getSimilarity();
	
	
	/**
	 * @return weight which represents the importance of this node among
	 * other nodes in this particular cluster. 
	 * The weight is a float number [0..1]. The sum of all node weights 
	 * inside each cluster equals 1.
	 */
	public float getWeight();
	
	
	/**
	 * @return true if the matching has been reversed.
	 * (=> resource and query node have been switched at similarity calculation)
	 */
	public boolean isReversed();
	
	
	/**
	 * @return a  list of objects implementing the PropertyMatchingResult 
	 * interface. Each of this objects holds information about the matching 
	 * of a certain property of a node from a query graph with a coersponding 
	 * property of a coresponding node from a resource graph. The list returned 
	 * does not contain all properties of the node, but only those of them which 
	 * have been specified in the matching description and thus considered 
	 * by the matching engine. 
	 * If the list returned is empty, is means that this node similarity 
	 * is merely based on the node similarity itself without considering 
	 * any properties.
	 */	
	public List getPropertyMatchingResultList ();
}
