package de.fuberlin.wiwiss.semmf.result;

import com.hp.hpl.jena.rdf.model.RDFNode;

/**
 * This interface provides methods for representing the matching result of 
 * properties of a certain node type. 
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modivied 29.11.2006
 */
public interface PropertyMatchingResult {

	/**
	 * @return RDFNode object representing the value of a particular property
	 * of a particular node from the query graph.
	 */
	public RDFNode getQueryPropVal();
	
	
	/**
	 * @return RDFNode object representing the value of a particular property
	 * of a particular node from the resource graph. 
	 */	
	public RDFNode getResPropVal();
	
	
	/**
	 * @return label of the property
	 */
	public String getLabel();
	
	
	/**
	 * @return similarity of both property values 
	 */	
	public float getSimilarity();
	
	
	/**
	 * @return true if the matching has been reversed.
	 * (=> resource and query properties have been switched at similarity calculation)
	 */
	public boolean isReversed();
	
	
	/**
	 * @return weight which represents the importance of this property among
	 * other properties of a single node type.  
	 * The weight is a float number [0..1]. The sum of all property weights 
	 * equals 1.
	 */	
	public float getWeight();
}
