package de.fuberlin.wiwiss.semmf.result.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Iterator;

import de.fuberlin.wiwiss.semmf.engine.ClusterSimComparator;
import de.fuberlin.wiwiss.semmf.engine.GraphSimComparator;
import de.fuberlin.wiwiss.semmf.result.GraphMatchingResult;
import de.fuberlin.wiwiss.semmf.result.ClusterMatchingResult;
import de.fuberlin.wiwiss.semmf.result.MatchingResult;

/**
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified on 29.11.2006
 */
public class MatchingResultImpl implements MatchingResult {
	
	
	/**
	 * List holding GraphMatchingResults
	 */
	private List gmdList = new ArrayList();
	
	
	/**
	 * Iterator over gmdList
	 */
	private Iterator it;
	
	
	/**
	 * Constructor
	 * @param gmdList List holding GraphMatchingResults
	 */
	public MatchingResultImpl (List gmdList) {
		
		this.gmdList = gmdList;
		this.it = this.gmdList.iterator();
	}
	
	
	/**
	 * @return the number of GraphMatchingResults
	 */
	public int count() {
		
		return this.gmdList.size();
	}
	
	
	/**
	 * sorts all GraphMatching results by their overall similarity in descending order
	 */
	public void sortByGraphSim () {
		
		Collections.sort(this.gmdList, new GraphSimComparator());
			
		// set the iterator to first element
		this.it = this.gmdList.iterator();
	}
	
	
	/**
	 * sorts all GraphMatching results by the given cluster similarity in descending order
	 * @param clusterLabel label provided in a matching description
	 */
	public void sortByClusterSim (String clusterLabel) {

		String cLabel = "#####";
		int i=-1;	
		Iterator itC = ((GraphMatchingResult) gmdList.get(0)).getClusterMatchingResultList().iterator();

		while (itC.hasNext() && !clusterLabel.equalsIgnoreCase(cLabel)) {
			i++;
			cLabel = ((ClusterMatchingResult) itC.next()).getLabel();
		}
		
		Collections.sort(this.gmdList, new ClusterSimComparator(i));
		
		// create a new iterator
		this.it = this.gmdList.iterator();
	}
	
	
	/**
	 * sets the index of the Iterator to the first (best ranked) element in the List
	 */
	public void setToFirst () {
		
		this.it = this.gmdList.iterator();
	}
	
	
	/**
	 * @return the best ranked GraphMatchingResult
	 */
	public GraphMatchingResult getFirst() {
		
		return (GraphMatchingResult) this.gmdList.get(0);
	}
	
	
	/**
	 * @return true is the is a next element in the ranked list of GraphMatchingResults
	 */
	public boolean hasNext() {
		
		return this.it.hasNext();
	}
	
	
	/**
	 * @return the next element in the ranked list of GraphMatchingResults
	 */
	public GraphMatchingResult next() {
		
		return (GraphMatchingResult) this.it.next();		
	}

}
