package de.fuberlin.wiwiss.semmf.result.impl;

import java.util.List;
import java.util.ArrayList;


import com.hp.hpl.jena.rdf.model.RDFNode;

import de.fuberlin.wiwiss.semmf.result.NodeMatchingResult;

/**
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified on 29.11.2006
 */
public class NodeMatchingResultImpl implements NodeMatchingResult {

	
	public RDFNode queryNode;
	public RDFNode resNode;
	public String label;
	public float sim;
	public float weight;
	public boolean reversed;
	public List propertyMatchingResultList = new ArrayList();
	
	
	/* **********************************************************************
	 * 		 Implementation of the NodeMatchingResult interface 
	 * **********************************************************************
	 */
	
	
	/** 
	 * @return RDFNode from a query graph
	 */
	public RDFNode getQueryNode() {
		
		return this.queryNode;
	}
	
	
	/** 
	 * @return RDFNode resource graph
	 */
	public RDFNode getResNode() {
		
		return this.resNode;
	}
	
	
	/**
	 * @return node label specified in a matching description.
	 */	
	public String getLabel() {
		
		return this.label;
	}
	
	
	/**
	 * @return similarity value of both nodes.
	 * If the node is a resource having properties this similarity value 
	 * includes the similarity of the nodes and the similarities of 
	 * their properties.
	 */
	public float getSimilarity() {
		
		return this.sim;
	}
	
	
	/**
	 * @return weight which represents the importance of this node among
	 * other nodes in this particular cluster. 
	 * The weight is a float number [0..1]. The sum of all node weights 
	 * inside each cluster equals 1.
	 */
	public float getWeight() {
		
		return this.weight;
	}
	
	
	/**
	 * @return true if the matching has been reversed.
	 * (=> resource and query node have been switched at similarity calculation)
	 */
	public boolean isReversed() {
		
		return this.reversed;
	}
	
	
	/**
	 * @return List of objects implementing the PropertyMatchingResult 
	 * interface. Each of this objects holds information about the matching 
	 * of a certain property of a node from a query graph with a coersponding 
	 * property of a coresponding node from a resource graph. The list returned 
	 * does not contain all properties of the node, but only those of them which 
	 * have been specified in the matching description and thus considered 
	 * by the matching engine. 
	 * If the list returned is empty, is means that this node similarity 
	 * is merely based on the node similarity itself without considering 
	 * any properties.
	 */	
	public List getPropertyMatchingResultList() {
		
		return this.propertyMatchingResultList;
	}
}
