package de.fuberlin.wiwiss.semmf.taxon;

import java.util.Set;
import java.util.HashSet;
import java.util.Iterator;

/**
 * A class representing a concept from a taxonomy, having one or more
 * super concepts (multiple positions in the concept hierarchy !!!) 
 * but NO descendants. This property of BottomConcepts has a great impact
 * on the matching process because all the positions have to be respected
 * in order to find the best possible match !!!
 * Each concept is an URI-denoted RDF-Node from an underlying taxonomy.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.2
 * last modified 29.11.2006 
 */
public class BottomConcept extends Concept{
	
    
    /**
     * Concept positions in the taxonomy.
     * NOTE: BottomConcepts are allowed to have more than one position
     * (= more than one SuperConcept).  
     */
	private Set conceptPositions;
	
	
	/**
	 * Constructor.
	 * @param URI URI of this BottomConcept
	 */
	public BottomConcept(String URI) {
				
		super(URI);
		this.type = 'b';
		this.conceptPositions = new HashSet();
	}
	
	
	/**
	 * Adds a new ConceptPosition of this BottomConcept
	 * @param cp the concept position to be added
	 */
	public void addConceptPosition (ConceptPosition cp) {
		
		this.conceptPositions.add(cp);		
	}
	
	
	/**
	 * @return Iterator over all concept positions
	 */
	public Iterator getConceptPositions() {
		
		return this.conceptPositions.iterator();
	}

}
