package de.fuberlin.wiwiss.semmf.taxon;

/**
 * This class describes the position of a concept in the concept hierarchy.
 * 
 * The concept position is indicated by the level in a concept hierarchy
 * (the level is used to calculate the milestone of a given concept) and
 * by a reference to the super concept (in this way all concepts create a 
 * taxonomy tree, allowing the matching engine to traverse along the path
 * to the root concept and by these means to determine the closest common 
 * parent of two given concepts as the intersection of their paths).
 * 
 * Note that a particular concept (at this time it only refers to BottomConcepts)
 * may have more than one position in the hierarchy 
 * e.g. to have more than one super concept.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.1
 * last modified 29.11.2006
 */
public class ConceptPosition {

    
	/**
	 * Taxonomy level at which a concept is located
	 */
	private int level;

	
	/**
	 * Reference to a super concpet of a concept having his position.
	 */
	private SuperConcept superConcept;
	
	
	/**
	 * Constructor.
	 * @param level taxonomy level
	 * @param sc reference to a SuperConcept of a concept having this
	 * 			 position in the taxonomy tree. 
	 */
	public ConceptPosition (int level, SuperConcept sc) {
		
		this.level = level;
		this.superConcept = sc;
	}	
	
	
	/**
	 * @return true if this position is a position of a root concept.
	 * A root concept is located at level=0 and has not SuperConcepts.
	 */
	public boolean isRoot() {
		
		if (this.superConcept == null)
			return true;
		else
			return false;
	}
	
	
	/**
	 * @return the level of this concept position
	 */
	public int getLevel() {
		
		return this.level;
	}
	
	
	/**
	 * @return the reference to a SuperConcept of this concept position
	 */
	public SuperConcept getSuperConcept() {
		
		return this.superConcept;
	}
}
