package de.fuberlin.wiwiss.semmf.taxon;

/**
 * This class is a milestone calculator using an exponential function
 * m(level) = 0.5 * pow (k, level), where k is a parameter passed 
 * to the constructor. The milestone values decrease exponentially 
 * allong the hierarchy levels.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public class ExpMilestCalc implements MilestoneCalculator {
	
	
	/**
	 * Parameter used in the milestone formula (0.5 / Math.pow(k, conceptLevel))
	 * K is a factor larger than 1 that indicates the rate at which the
	 * milestone value decreases along the hierarchy.
	 */
	private float k;
	
	
	/**
	 * Constructor
	 * @param k indicates the rate at which the milestone value decreases along
	 * 			the hierarchy.
	 */
	public ExpMilestCalc (float k) {
	
		this.k = k;
	}
	
	
	/**
	 * @param deepestLevel index of the deepest level (= number of levels - 1)
	 * @return an array of float values for all taxonomy levels starting from 
	 * 		   0 (root element) and ending at the deepest level. 
	 */
	public float[] calculateMilestones (int deepestLevel) {
		
		// number of levels = deepest level + 1 
		float[] milestones = new float[deepestLevel+1];

		for (int level = 0; level <= deepestLevel; ++level) {			
			milestones[level] = (float) (0.5/(Math.pow(this.k, level)));
		}

		return milestones;
	}

}
