package de.fuberlin.wiwiss.semmf.taxon;

/**
 * This class is a milestone calculator using a linear formula:  
 * m(level) = 1 - (level / deepestLevel).
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.0
 * last modified 29.11.2006
 */
public class LinMilestCalc implements MilestoneCalculator {

	
	/**
	 * @param deepestLevel index of the deepest level (= number of levels - 1)
	 * @return an array of float values for all taxonomy levels starting from 
	 * 		   0 (root element) and ending at the deepest level. 
	 */
	public float[] calculateMilestones (int deepestLevel) {
		
		float[] milestones = new float[deepestLevel+1];
		
		for (int level = 0; level <= deepestLevel; level++) {
			// either of the operands has to be float in order to get float result
			milestones[level] = 1 - (level / (float) deepestLevel);
		}
		
		return milestones;
	}
}
