package de.fuberlin.wiwiss.semmf.taxon;

/**
 * A class representing a concept from a taxonomy, having one or more
 * descendants but only ONE parent concept. 
 * Each concept is an URI-denoted RDF-Node from an underlying taxonomy.
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.2
 * last modified 29.11.2006 
 */
public class SuperConcept extends Concept {
	
    /**
     * Object representing the position of this SuperConcept in a 
     * concept hierarchy.
     */
	private ConceptPosition conceptPosition;	
	
	
	/**
	 * Constructor. Creates a new SuperConcept with no specified position
	 * @param URI URI of this SuperConcept
	 */
	public SuperConcept(String URI) {
	    
	    this(URI, null);
	}
	
	/**
	 * Constructor.
	 * @param URI - URI of this SuperConcept
	 * @param cp  - position of this concept in the concept hierarchy
	 */
	public SuperConcept(String URI, ConceptPosition cp) {
		
		super(URI);
		this.conceptPosition = cp;
		this.type = 's';
	}
	
	
	/**
	 * Sets the position of this concept in the concept hierarchy
	 */
	public void setConceptPosition(ConceptPosition cp) {
	    
	    this.conceptPosition = cp;
	}
	
	
	/**
	 * @return the concept position
	 */
	public ConceptPosition getConceptPosition() {
		
		return this.conceptPosition;
	}

}
