package de.fuberlin.wiwiss.semmf.vocabulary;

import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.rdf.model.Property;

/**
 * Vocabulary (in form of Jena objects) used for creating matching descriptions. 
 * 
 * @author Radoslaw Oldakowski 
 * @version 1.2
 * 
 * last modified 29.11.2006
 */
public abstract class MD {

	/**
	 * Used to create instances of Jena classes: Resource and Property
	 */
	private static Model m = ModelFactory.createDefaultModel();
	
	/**
	 * Namespace of the vocabulary
	 */	
	public static final String NS = "http://semmf.ag-nbi.de/vocabulary/1.1/semmf.rdfs#";

	// === Class definitions ===
	public static final Resource GraphMatchingDescription = m.createResource(NS + "GraphMatchingDescription");	
	public static final Resource ClusterMatchingDescription = m.createResource(NS + "ClusterMatchingDescription");
	public static final Resource NodeMatchingDescription = m.createResource(NS + "NodeMatchingDescription");
	public static final Resource PropertyMatchingDescription = m.createResource(NS + "PropertyMatchingDescription");
	
	public static final Resource NumericMatcher = m.createResource(NS + "NumericMatcher");
	public static final Resource StringMatcher = m.createResource(NS + "StringMatcher");
	public static final Resource TaxonomicMatcher = m.createResource(NS + "TaxonomicMatcher");
	public static final Resource Taxonomy = m.createResource(NS + "Taxonomy");
	public static final Resource ExpMilestCalc = m.createResource(NS + "ExpMilestCalc");
	public static final Resource LinMilestCalc = m.createResource(NS + "LinMilestCalc");
	
	
	// === Property definitions ===
	// --- domain: GraphMatchingDescription
	public static final Property queryModelURL = m.createProperty(NS, "queryModelURL");
	public static final Property resModelURL = m.createProperty(NS, "resModelURL");
	public static final Property queryGraphURI = m.createProperty(NS, "queryGraphURI");
	public static final Property resGraphURIpath = m.createProperty(NS, "resGraphURIpath");
	public static final Property hasClusterMatchingDescriptions = m.createProperty(NS, "hasClusterMatchingDescriptions");
	
	// domain: ClusterMD, NodeMD, PropertyMD
	public static final Property label = m.createProperty(NS, "label");
	public static final Property weight = m.createProperty(NS, "weight");
	
	// domain: ClusterMatchingDescription
	public static final Property hasNodeMatchingDescriptions = m.createProperty(NS, "hasNodeMatchingDescriptions");
	
	// domain: NodeMD, PropertyMD
	public static final Property useMatcher = m.createProperty(NS, "useMatcher");
	public static final Property reverseMatching = m.createProperty(NS, "reverseMatching");
	
	// domain: NodeMatchingDescription
	public static final Property queryNodePath = m.createProperty(NS, "queryNodePath");
	public static final Property resNodePath = m.createProperty(NS, "resNodePath");		
	public static final Property hasPropertyMatchingDescriptions = m.createProperty(NS, "hasPropertyMatchingDescriptions");
	
	// domain: PropertyMatchingDescription
	public static final Property queryPropURI = m.createProperty(NS, "queryPropURI");
	public static final Property resPropURI = m.createProperty(NS, "resPropURI");
	
	// domain: NumericMatcher
	public static final Property decreaseSim = m.createProperty(NS, "decreaseSim");
	public static final Property maxDevFraction = m.createProperty(NS, "maxDevFraction");
	
	// domain: StringMatcher
	public static final Property caseSensitive = m.createProperty(NS, "caseSensitive");
	
	// domain: TaxonomicMatcher
	public static final Property simInheritance = m.createProperty(NS, "simInheritance");
	public static final Property taxonomy = m.createProperty(NS, "taxonomy");
	public static final Property useMilestoneCalc = m.createProperty(NS, "milestoneCalc");
	
	// domain: Taxonomy
	public static final Property taxonomyURL = m.createProperty(NS, "taxonomyURL");
	public static final Property rootConceptURI = m.createProperty(NS, "rootConceptURI");
	
	// domain: ExpMilestCalc
	public static final Property k_factor = m.createProperty(NS, "k_factor");
}